@@ -54,8 +54,8 @@ class PatternCompileTest(test.TestCase):
 
     def test_wrong_object(self):
         msg_regex = '^Unknown object .* requested to compile'
-        self.assertRaisesRegexp(TypeError, msg_regex,
-                                compiler.PatternCompiler(42).compile)
+        self.assertRaisesRegex(TypeError, msg_regex,
+                               compiler.PatternCompiler(42).compile)
 
     def test_empty(self):
         flo = lf.Flow("test")
@@ -73,7 +73,7 @@ class PatternCompileTest(test.TestCase):
             compiler.PatternCompiler(flo).compile())
         self.assertEqual(8, len(g))
 
-        order = g.topological_sort()
+        order = list(g.topological_sort())
         self.assertEqual(['test', 'a', 'b', 'c',
                           "sub-test", 'd', "sub-test[$]",
                           'test[$]'], order)
@@ -430,7 +430,7 @@ class PatternCompileTest(test.TestCase):
         self.assertTrue(g.has_edge(flow, a))
         self.assertTrue(g.has_edge(a, empty_flow))
 
-        empty_flow_successors = g.successors(empty_flow)
+        empty_flow_successors = list(g.successors(empty_flow))
         self.assertEqual(1, len(empty_flow_successors))
         empty_flow_terminal = empty_flow_successors[0]
         self.assertIs(empty_flow, empty_flow_terminal.flow)
@@ -458,18 +458,18 @@ class PatternCompileTest(test.TestCase):
             test_utils.DummyTask(name="a")
         )
         e = engines.load(flo)
-        self.assertRaisesRegexp(exc.Duplicate,
-                                '^Atoms with duplicate names',
-                                e.compile)
+        self.assertRaisesRegex(exc.Duplicate,
+                               '^Atoms with duplicate names',
+                               e.compile)
 
     def test_checks_for_dups_globally(self):
         flo = gf.Flow("test").add(
             gf.Flow("int1").add(test_utils.DummyTask(name="a")),
             gf.Flow("int2").add(test_utils.DummyTask(name="a")))
         e = engines.load(flo)
-        self.assertRaisesRegexp(exc.Duplicate,
-                                '^Atoms with duplicate names',
-                                e.compile)
+        self.assertRaisesRegex(exc.Duplicate,
+                               '^Atoms with duplicate names',
+                               e.compile)
 
     def test_retry_in_linear_flow(self):
         flo = lf.Flow("test", retry.AlwaysRevert("c"))
@@ -599,7 +599,7 @@ class PatternCompileTest(test.TestCase):
         self.assertIs(c2, g.node['b']['retry'])
         self.assertIs(c2, g.node['c']['retry'])
         self.assertIs(c1, g.node['c2']['retry'])
-        self.assertIs(None, g.node['c1'].get('retry'))
+        self.assertIsNone(g.node['c1'].get('retry'))
 
     def test_retry_subflows_hierarchy(self):
         c1 = retry.AlwaysRevert("c1")
@@ -624,4 +624,4 @@ class PatternCompileTest(test.TestCase):
         self.assertIs(c1, g.node['d']['retry'])
         self.assertIs(c1, g.node['b']['retry'])
         self.assertIs(c1, g.node['c']['retry'])
-        self.assertIs(None, g.node['c1'].get('retry'))
+        self.assertIsNone(g.node['c1'].get('retry'))
